@@ -15,11 +15,11 @@ App::Rgit - Backend that supports the rgit utility.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 DESCRIPTION
 
@@ -42,13 +42,14 @@ sub new {
   git  => $args{git},
  );
  return unless defined $config;
+ my $command = App::Rgit::Command->new(
+  cmd  => $args{cmd},
+  args => $args{args},
+ );
+ return unless defined $command;
  $class->SUPER::new(
   config  => $config,
-  command => App::Rgit::Command->new(
-   cmd   => $args{cmd},
-   args  => $args{args},
-   repos => $config->repos,
-  )
+  command => $command,
  );
 }
 
